ChainEvent

Enum ChainEvent 

pub enum ChainEvent {
    BlockConnected {
        hash: BlockHash,
        height: u32,
        num_txs: usize,
    },
    BlockDisconnected {
        hash: BlockHash,
        height: u32,
    },
    TransactionAddedToMempool {
        txid: Txid,
        vsize: u64,
        fee: i64,
    },
    TransactionRemovedFromMempool {
        txid: Txid,
        reason: MempoolRemovalReason,
    },
}
A chain state change event.

Variants



BlockConnected

A new block was connected to the active chain tip.

Fields

hash: BlockHash

The block hash.

height: u32

The height of the connected block.

num_txs: usize

Number of transactions in the block.



BlockDisconnected

A block was disconnected from the active chain tip (reorg).

Fields

hash: BlockHash

The block hash that was disconnected.

height: u32

The height that was disconnected.



TransactionAddedToMempool

A transaction was accepted into the mempool.

Fields

txid: Txid

The transaction id.

vsize: u64

Virtual size in vbytes.

fee: i64

Fee in satoshis.



TransactionRemovedFromMempool

A transaction was removed from the mempool.

Fields

txid: Txid

The transaction id.

reason: MempoolRemovalReason

Reason for removal.