pub enum ChainEvent {
BlockConnected {
hash: BlockHash,
height: u32,
num_txs: usize,
},
BlockDisconnected {
hash: BlockHash,
height: u32,
},
TransactionAddedToMempool {
txid: Txid,
vsize: u64,
fee: i64,
},
TransactionRemovedFromMempool {
txid: Txid,
reason: MempoolRemovalReason,
},
}Expand description
A chain state change event.
Variants
BlockConnected
A new block was connected to the active chain tip.
Fields
BlockDisconnected
A block was disconnected from the active chain tip (reorg).
Fields
TransactionAddedToMempool
A transaction was accepted into the mempool.
TransactionRemovedFromMempool
A transaction was removed from the mempool.